@@ -80,15 +80,15 @@ where
     ) -> Result<Self::Item> {
         // materialize the actual (offset, key, value) triples for the matching bits
         let data = if matching.any() {
-            tracing::debug!("loading leaf {:?}", range);
+            tracing::trace!("loading leaf {:?}", range);
             let leaf = leaf.load()?;
             let offsets = matching
                 .iter()
                 .enumerate()
                 .filter(|(_, m)| **m)
                 .map(|(i, _)| range.start + i as u64);
-            let keys = index.select_keys(&matching);
-            let elems: Vec<V> = leaf.as_ref().select(&matching)?;
+            let keys = index.select_keys(matching);
+            let elems: Vec<V> = leaf.as_ref().select(matching)?;
             offsets
                 .zip(keys)
                 .zip(elems)
@@ -442,7 +442,7 @@ where
         #[cfg(feature = "metrics")]
         let _timer = prom::BRANCH_LOAD_HIST.start_timer();
         Ok({
-            let bytes = self.get_block(&link)?;
+            let bytes = self.get_block(link)?;
             let (children, byte_range) =
                 deserialize_compressed(secrets.index_key(), nonce::<T>(), &bytes)?;
             Branch::<T>::new(children, byte_range)
@@ -472,14 +472,14 @@ where
     ) -> Result<Option<Branch<T>>> {
         let t0 = Instant::now();
         let result = Ok(if let Some(link) = &index.link {
-            let bytes = self.get_block(&link)?;
+            let bytes = self.get_block(link)?;
             let (children, byte_range) =
                 deserialize_compressed(secrets.index_key(), nonce::<T>(), &bytes)?;
             Some(Branch::<T>::new(children, byte_range))
         } else {
             None
         });
-        tracing::debug!("load_branch {}", t0.elapsed().as_secs_f64());
+        tracing::trace!("load_branch {}", t0.elapsed().as_secs_f64());
         result
     }
 
